Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1648)

Unified Diff: base/task_scheduler/task_scheduler.h

Issue 2729523006: Remove the |max_threads| argument from CreateAndSetSimpleTaskScheduler(). (Closed)
Patch Set: fix build error Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | base/task_scheduler/task_scheduler.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/task_scheduler/task_scheduler.h
diff --git a/base/task_scheduler/task_scheduler.h b/base/task_scheduler/task_scheduler.h
index da2cb79504e9c2472758abcfce4f5ddd51246686..4b07c88998ba922f46914f7f88055b939e1947cc 100644
--- a/base/task_scheduler/task_scheduler.h
+++ b/base/task_scheduler/task_scheduler.h
@@ -6,6 +6,7 @@
#define BASE_TASK_SCHEDULER_TASK_SCHEDULER_H_
#include <memory>
+#include <string>
#include <vector>
#include "base/base_export.h"
@@ -107,10 +108,13 @@ class BASE_EXPORT TaskScheduler {
// synchronization is required to use the post_task.h API after registering a
// new TaskScheduler.
- // Creates and sets a task scheduler with one worker pool that can have up to
- // |max_threads| threads. CHECKs on failure. For tests, prefer
- // base::test::ScopedTaskScheduler (ensures isolation).
- static void CreateAndSetSimpleTaskScheduler(int max_threads);
+#if !defined(OS_NACL)
+ // Creates and sets a task scheduler using default params. |name| is used to
+ // label threads and histograms. It should identify the component that calls
+ // this. CHECKs on failure. For tests, prefer base::test::ScopedTaskScheduler
+ // (ensures isolation).
+ static void CreateAndSetSimpleTaskScheduler(const std::string& name);
+#endif // !defined(OS_NACL)
// Creates and sets a task scheduler with custom worker pools. CHECKs on
// failure. |worker_pool_params_vector| describes the worker pools to create.
« no previous file with comments | « no previous file | base/task_scheduler/task_scheduler.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698